@@ -28,6 +28,10 @@ from cloudmesh.common.systeminfo import get_platform
 from cloudmesh.common.util import path_expand
 from cloudmesh.common.util import readfile
 from cloudmesh.common.systeminfo import os_is_windows
+from cloudmesh.common.systeminfo import os_is_mac
+from cloudmesh.common.systeminfo import os_is_linux
+from cloudmesh.common.util import is_gitbash
+
 
 
 # from functools import wraps
@@ -457,6 +461,7 @@ class Shell(object):
         try:
             shutil.rmtree(path_expand(top))
         except Exception as e:
+            print(e)
             pass
             # print(e.strerror)
             # assert False, f"Directory {top} could not be deleted"
@@ -472,15 +477,22 @@ class Shell(object):
         os.system(command)
 
     @staticmethod
-    def browser(filename):
-        data = {
-            'engine': 'python -m webbrowser',
-            'file': filename
-        }
-        if 'file:' not in filename and 'http' not in filename:
-            os.system("python -m webbrowser -t file:///{file}".format(**data))
+    def browser(filename=None, engine='python -m webbrowser -t'):
+        if ".svg" in filename:
+            if os_is_linux():
+                if engine.startswith("chrome"):
+                    os.system(f"chromium {filename}")
+                else:
+                    os.system(f"gopen {filename}")
+            elif os_is_mac():
+                os.system(f"open {filename}")
+            elif os_is_windows():
+                raise NotImplementedError("IMplement me in Shell.browser")
         else:
-            os.system("python -m webbrowser -t {file}".format(**data))
+            if 'file:' not in filename and 'http' not in filename:
+                os.system(f"{engine} file:///{filename}")
+            else:
+                os.system(f"{engine} {file}".format(**data))
 
     @staticmethod
     def terminal_title(name):
@@ -652,11 +664,11 @@ class Shell(object):
         :param args:
         :return:
         """
-        NotImplementedInWindows()
-        # TODO: replace with file read and reading the content. We need to deal
-        #       with line endings and add maybe a flag endings="unix"/"windows".
-        #       check the finction readlines.
-        return cls.execute('cat', args)
+        if os_is_windows() and is_gitbash():
+            content = readfile(args[0])
+            return content
+        else:
+            return cls.execute('cat', args)
 
     @classmethod
     def git(cls, *args):
@@ -665,7 +677,6 @@ class Shell(object):
         :param args:
         :return:
         """
-        NotImplementedInWindows()
         return cls.execute('git', args)
 
     # noinspection PyPep8Naming
@@ -727,8 +738,9 @@ class Shell(object):
         :param args:
         :return:
         """
-        NotImplementedInWindows()
-        # TODO: reimplement with readlines
+        if not is_gitbash():
+            content = Shell.cat(args[0]).splitlines()
+            return content[0]
         return cls.execute('head', args)
 
     @classmethod
@@ -1002,8 +1014,8 @@ class Shell(object):
         :param args:
         :return:
         """
-        NotImplementedInWindows()
-        # TODO: see cm_grep
+        if os_is_windows() and not is_gitbash():
+            NotImplementedInWindows()
         return cls.execute('fgrep', args)
 
     @classmethod
@@ -1014,7 +1026,8 @@ class Shell(object):
         :param args:
         :return:
         """
-        NotImplementedInWindows()
+        if os_is_windows() and not is_gitbash():
+            NotImplementedInWindows()
         return cls.execute('grep', args)
 
     @classmethod
@@ -1235,6 +1248,16 @@ class Shell(object):
             print("         We recommend you update your pip  with \n")
             print("             pip install -U pip\n")
 
+    @classmethod
+    def copy(cls, source, destination, expand=False):
+        if expand:
+            s = path_expand(source)
+            d = path_expand(destination)
+        else:
+            s=source
+            d = destination
+        shutil.copy2(s, d)
+
     @classmethod
     def mkdir(cls, directory):
         """
